import matplotlib.pyplot as plt
import numpy as np
# set dpi
plt.rcParams['figure.dpi'] = 300

# Creating some data

x = [3.9,3.7,4.4]
y = [80.5, 82.9, 79.9]  # Random values for y-axis
z = [600, 400, 800]  # Random values for the size of the bubble

# Create the bubble chart
plt.figure(figsize=(3, 3))

plt.rcParams['font.family'] = 'DejaVu Sans'
plt.grid(axis='y', linestyle='--', alpha=0.5, zorder=-10)

bubble = plt.scatter(x, y, c=[4,5,6], s=40, alpha=1, marker='x', cmap='tab10')
# put label on each bubble
label = ["LDB-Line", "LDB-Block (Original)", "LDB-Function"]

plt.text(x[0], y[0]-0.6, label[0], ha='center', va='center', fontsize=8, color='black')
plt.text(x[1] + 0.3, y[1], label[1], ha='center', va='center', fontsize=8, color='black')
plt.text(x[2] - 0.05, y[2] - 0.6, label[2], ha='center', va='center', fontsize=8, color='black')

# Draw a horizontal line at 73.8 with label baseline
plt.axhline(y=73.8, color='black', linestyle='--', linewidth=0.5, label='Baseline')
# Draw a label baseline
plt.text(4.4, 73.8 + 0.5, "Baseline", ha='right', va='center', fontsize=10, color='black')

plt.xlim(3.5, 4.55)
plt.ylim(73, 85)

# Add labels and title
plt.xlabel('# Token (M)', fontsize=12)
# same inteval x ticks
plt.xticks(np.arange(3.5, 4.55, 0.5), labels=['3.5', '4.0', '4.5'])

plt.ylabel('Accuracy (%)', fontsize=12)
#plt.title('Bubble Chart')
# Create a legend for different sizes
for size in [100,200,300]:
    plt.scatter([], [], s=size, color='k', alpha=0.5, label=" ")
#plt.legend(scatterpoints=1, frameon=False, title='# Token Cost', loc='lower right', ncol=3, columnspacing=0.1, handletextpad=0.1, fontsize=8, edgecolor='black', bbox_to_anchor=(1, 0.5))

plt.tight_layout()
# Show the plot
plt.savefig('bubble-acc.pdf', dpi=300)
