import matplotlib.pyplot as plt

# Update the data to only three categories
plt.rcParams['figure.dpi'] = 300
# set size of the figure
plt.figure()
# change font to time new roman
plt.rcParams['font.family'] = 'DejaVu Sans'
categories = ['Easy', 'Medium', 'Hard']
values_without_debugging = [0.951, 0.828, 0.733]
values_ldb = [0.963, 0.876, 0.824]
values_with_sd = [0.963, 0.868, 0.779]
bar_width = 0.2
gap_width = 0.02
# Set up the index location for the bars
index = range(len(categories))

# Create the figure and axis objects
fig, ax = plt.subplots(figsize=(8, 4))

# Create the bars for without debugging
ax.bar(index, values_without_debugging, bar_width, label='w/o \ndebugging', color='#f2cc8f', alpha=0.8, zorder=10)

# Create the bars for self-debugging
ax.bar([(i + bar_width+ gap_width) for i in index], values_with_sd, bar_width, label='Self-Debugging\n(Chen et al., 2023)', color='#81b29a', hatch='\\', alpha=0.8, zorder=10)

# Create the bars for ldb
ax.bar([(i + 2 * bar_width+ 2*gap_width) for i in index], values_ldb, bar_width, label='LDB\n(ours)', color='#c1121f', hatch='///', alpha=0.8, edgecolor='black', zorder=10)

# Add the text labels above the bars
for i in index:
    ax.text(i, values_without_debugging[i], str(values_without_debugging[i]*100), ha='center', va='bottom', fontsize=14,zorder=5)
    ax.text(i + bar_width + gap_width, values_with_sd[i], str(values_with_sd[i]*100), ha='center', va='bottom', fontsize=14,zorder=5)
    ax.text(i + bar_width + gap_width, values_with_sd[i] + 0.035, '(+' + str(round((values_with_sd[i]-values_without_debugging[i]),3)*100) + ')', ha='center', va='bottom', fontsize=11,zorder=5, color='green')
    ax.text(i + 2*bar_width + 2*gap_width, values_ldb[i], str(round(values_ldb[i]*100, 1)), ha='center', va='bottom', fontsize=14, weight='bold',zorder=5)
    ax.text(i + 2*bar_width + 2*gap_width, values_ldb[i] + 0.035, '(+' + str(round((values_ldb[i]-values_without_debugging[i]),3)*100) + ')', ha='center', va='bottom', fontsize=11,zorder=5, color='green')
    

# Set the labels, title, and legend
#ax.set_xlabel('Difficulty', fontsize=14)
ax.set_ylabel('  TransCoder Accuracy (%)', fontsize=18)
#ax.set_title('(b)')
ax.set_xticks([i + bar_width + gap_width for i in index])
ax.set_xticklabels(categories, fontsize=20)
ax.set_ylim(0.60, 1.03)
ax.set_yticklabels(['60', '', '70', '', '80', '', '90', '', '100', '%'], fontsize=14)
# put legend on the top outside the figure
ax.legend(fontsize=16, ncol=3, loc='upper center', bbox_to_anchor=(0.5, 1.3), frameon=False)
# add grid
ax.grid(axis='y', linestyle='--', alpha=0.7, zorder=-5)

# Display the plot
plt.tight_layout()
plt.savefig('/home/zilong-exp/Projects/DebugAgent-refactor/figure/difficulty.pdf')
