import matplotlib.pyplot as plt
import numpy as np
plt.rcParams['figure.dpi'] = 300
# set size of the figure
plt.figure(figsize=(6, 4))
# change font to time new roman
plt.rcParams['font.family'] = 'DejaVu Sans'
# Data for plotting
turns = np.array([i for i in range(11)])
ldb = np.array([73.8, 75.0, 76.8, 79.3, 80.5, 81.7, 81.7, 82.3, 82.3, 82.3, 82.9])
ut_expl = np.array([73.8, 78.7, 81.1, 81.1, 81.1, 81.1, 81.1, 81.1, 81.1, 81.1, 81.1])
ut_trace = np.array([73.8, 79.3, 79.9, 79.9, 79.9, 79.9, 79.9, 79.9, 79.9, 79.9, 80.5])
simple = np.array([73.8, 74.4, 75.0, 75.6, 75.6, 75.6, 75.6, 76.2, 76.2, 76.2, 76.2])
cmap = plt.get_cmap('Set2')
colors = ['#06D6A0', '#118AB2', '#EF476F']#cmap(np.linspace(0.5, 1, 4))

# Plotting the lines


plt.plot(turns, ut_expl, marker='1', label='SelfDebugging (+Expl) (Chen et al., 2023)', color=colors[1])
plt.plot(turns, simple, marker='3', label='Repeat Sampling', color='darkgray', linestyle='--')
plt.plot(turns, ut_trace, marker='2', label='SelfDebugging (+Trace) (Chen et al., 2023)', color=colors[0])

# Annotating the data points
for i, txt in enumerate(simple):
    if i == 0:
        continue
    if ~np.isnan(txt):
        plt.annotate(f'{txt}', (turns[i], simple[i]), textcoords="offset points", xytext=(5,-12), ha='center', color='darkgray', fontsize=9)
for i, txt in enumerate(ut_expl):
    if i == 0:
        continue
    if ~np.isnan(txt):
        plt.annotate(f'{txt}', (turns[i], ut_expl[i]), textcoords="offset points", xytext=(-5,-12), ha='center', color=colors[1], fontsize=9)
for i, txt in enumerate(ut_trace):
    if i == 0:
        continue
    if ~np.isnan(txt):
        plt.annotate(f'{txt}', (turns[i], ut_trace[i]), textcoords="offset points", xytext=(5,-12), ha='center', color=colors[0], fontsize=9)

plt.plot(turns, ldb, marker='o', label='LDB (ours)', color=colors[2], zorder=10)
for i, txt in enumerate(ldb):
    if ~np.isnan(txt):
        plt.annotate(f'{txt}', (turns[i], ldb[i]), textcoords="offset points", xytext=(5,-12), ha='center', color=colors[2], fontsize=9, weight='bold', zorder=10)


# Adding legend
# make the legend into two columns
plt.legend(loc='upper center', bbox_to_anchor=(0.5, 1.15), fontsize=9, ncol = 2, columnspacing=0.5, frameon=False)

# Adding titles and labels
#plt.title('HumanEval Accuracy vs. Debugging Turns', fontsize=12)
plt.xlabel('# Turns', size=12)
plt.ylabel('HumanEval Accuracy (%)', size=12)
plt.grid(color = 'lightgray', linestyle = '--', linewidth = 0.5)

# set the y-axis limit
plt.ylim(72, 83.5)
plt.xlim(-0.3, 10.5)
# Showing the plot
# layout tight
plt.tight_layout()
plt.savefig('../figure/turns.pdf')
